.. _timeseries:

Timeseries Primitives
=====================

.. currentmodule:: mlstars.custom

.. autosummary::
   :toctree: api/

   mlstars.custom.timeseries_preprocessing.cutoff_window_sequences
   mlstars.custom.timeseries_preprocessing.intervals_to_mask
   mlstars.custom.timeseries_preprocessing.rolling_window_sequences
   mlstars.custom.timeseries_preprocessing.time_segments_aggregate
   mlstars.custom.timeseries_anomalies.regression_errors
   mlstars.custom.timeseries_anomalies.find_anomalies